/******************************************************************************
 *
 * File:            PdfTools_Toolbox_Ptx.h
 *
 * Description:     Sub Header file for Toolbox SDK
 *
 * Author:          PDF Tools AG
 *
 * Copyright:       Copyright (C) 2024 - 2024 PDF Tools AG, Switzerland
 *                  All rights reserved.
 *
 * Notice:          By downloading and using this artifact, you accept PDF Tools AG's
 *                  [license agreement](https://www.pdf-tools.com/license-agreement/),
 *                  [privacy policy](https://www.pdf-tools.com/privacy-policy/),
 *                  and allow PDF Tools AG to track your usage data.
 *
 *****************************************************************************/

#ifndef PDFTOOLS_TOOLBOX_PTX_H__
#define PDFTOOLS_TOOLBOX_PTX_H__

#ifndef PDFTOOLS_TOOLBOX_CALL
#if defined(WIN32)
#define PDFTOOLS_TOOLBOX_CALL __stdcall
#else
#define PDFTOOLS_TOOLBOX_CALL
#endif
#endif

#include "PdfTools_Toolbox_Types.h"
#include "PdfTools_Toolbox_PtxSys.h"

#ifdef __cplusplus
extern "C"
{
#endif

#ifdef _UNICODE
#define Ptx_GetLastErrorMessage Ptx_GetLastErrorMessageW
#define Ptx_Sdk_Initialize      Ptx_Sdk_InitializeW

#define Ptx_Sdk_GetVersion Ptx_Sdk_GetVersionW

#define Ptx_Sdk_GetProducerFullName Ptx_Sdk_GetProducerFullNameW

#define Ptx_StringMap_Get      Ptx_StringMap_GetW
#define Ptx_StringMap_GetKey   Ptx_StringMap_GetKeyW
#define Ptx_StringMap_GetValue Ptx_StringMap_GetValueW
#define Ptx_StringMap_Set      Ptx_StringMap_SetW
#define Ptx_StringMap_SetValue Ptx_StringMap_SetValueW

#else
#define Ptx_GetLastErrorMessage Ptx_GetLastErrorMessageA
#define Ptx_Sdk_Initialize      Ptx_Sdk_InitializeA

#define Ptx_Sdk_GetVersion Ptx_Sdk_GetVersionA

#define Ptx_Sdk_GetProducerFullName Ptx_Sdk_GetProducerFullNameA

#define Ptx_StringMap_Get      Ptx_StringMap_GetA
#define Ptx_StringMap_GetKey   Ptx_StringMap_GetKeyA
#define Ptx_StringMap_GetValue Ptx_StringMap_GetValueA
#define Ptx_StringMap_Set      Ptx_StringMap_SetA
#define Ptx_StringMap_SetValue Ptx_StringMap_SetValueA

#endif

/******************************************************************************
 * Library
 *****************************************************************************/

/**
 * @brief Initializes the library.
 *
 * The function that <b>must</b> be called before any other API function.
 * Failing to invoke this function results in undefined behavior.
 */
PDFTOOLS_TOOLBOX_EXPORT void PDFTOOLS_TOOLBOX_CALL Ptx_Initialize();

/**
 * @brief Uninitializes the library.
 *
 * The function that <b>must</b> be called after all the other API functions.
 * Failing to invoke this function results in undefined behavior.
 */
PDFTOOLS_TOOLBOX_EXPORT void PDFTOOLS_TOOLBOX_CALL Ptx_Uninitialize();

/**
 * @brief Retrieves the last error code.
 *
 * When a function returns a value indicating a potential error, determine the error by a specific error code.
 * An error is confirmed if the error code differs from \ref ePtx_Error_Success.
 * @return    The error code that last was set.
 */
PDFTOOLS_TOOLBOX_EXPORT TPtx_ErrorCode PDFTOOLS_TOOLBOX_CALL Ptx_GetLastError();

/**
 * @brief Retrieves the last error message.
 *
 * Gets a detailed error message.
 *
 * @param[out] pBuffer The function has to be called twice, the first time by setting pBuffer to `NULL` to obtain the
 * actual buffer size and the second time with the allocated pBuffer and the buffer size obtained in the first call. The
 * return value of this function specifies the buffer size.
 * @param[in] nBufferSize The number of characters to be copied to `pBuffer`.
 *
 * @return   The amount of data written to the buffer `pBuffer`.
 *           `0` if there is an error.
 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_GetLastErrorMessageA(char* pBuffer, size_t nBufferSize);

/**
 * @brief Retrieve last error message.
 *
 * Gets a detailed error message.
 *
 * @param[out] pBuffer The function has to be called twice, the first time by setting pBuffer to `NULL` to obtain the
 * actual buffer size and the second time with the allocated pBuffer and the buffer size obtained in the first call. The
 * return value of this function specifies the buffer size.
 * @param[in] nBufferSize The buffer size of the retrieved string `pBuffer`.
 *
 * @return   The amount of data written to the buffer `pBuffer`.
 *           `0` if there is an error.
 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_GetLastErrorMessageW(WCHAR* pBuffer, size_t nBufferSize);

/**
 * @brief Set last error code and error message.
 *
 * Register errors by calling this function within a callback body.
 *
 * @param[in] iErrorCode Set error code.
 * @param[in] szErrorMessage Set null-terminated error message.
 */
PDFTOOLS_TOOLBOX_EXPORT void PDFTOOLS_TOOLBOX_CALL Ptx_SetLastErrorA(TPtx_ErrorCode iErrorCode,
                                                                     const char*    szErrorMessage);

/**
 * @brief Set last error code and error message.
 *
 * Register errors by calling this function within a callback body.
 *
 * @param[in] iErrorCode Set error code.
 * @param[in] szErrorMessage Set null-terminated error message.
 */
PDFTOOLS_TOOLBOX_EXPORT void PDFTOOLS_TOOLBOX_CALL Ptx_SetLastErrorW(TPtx_ErrorCode iErrorCode,
                                                                     const WCHAR*   szErrorMessage);

/******************************************************************************
 * Object
 *****************************************************************************/
/**
 * @brief Release object.
 *
 * Register errors by calling this function within a callback body.
 * Disposable objects should be properly disposed by using their respective close functions.
 *
 * @param[in] pObject Object to be released.
 */
PDFTOOLS_TOOLBOX_EXPORT void PDFTOOLS_TOOLBOX_CALL Ptx_Release(void* pObject);

/**
 * @brief Increase reference count of object.
 *
 * Internally, the reference count is incremented by `1`.
 *
 * @param[in,out] pObject Object which reference count should be incremented by `1`.
 */
PDFTOOLS_TOOLBOX_EXPORT void PDFTOOLS_TOOLBOX_CALL Ptx_AddRef(void* pObject);

/**
 * @brief Compare two native objects.
 *
 * Checks if two handles point to the same object.
 *
 * @param[in] pObject Pointer to one object.
 * @param[in] pOther Pointer to other object.
 *
 * @return   \ref TRUE if both pointers point to the same object; \ref FALSE otherwise.
 */
PDFTOOLS_TOOLBOX_EXPORT BOOL PDFTOOLS_TOOLBOX_CALL Ptx_Equals(void* pObject, void* pOther);

/**
 * @brief Get a hash code.
 *
 * Get a hash code for a given native object.
 *
 * @param[in] pObject Pointer to the object for which a hash code is calculated.
 *
 * @return   The hash code of the object.
 */
PDFTOOLS_TOOLBOX_EXPORT int PDFTOOLS_TOOLBOX_CALL Ptx_GetHashCode(void* pObject);
/******************************************************************************
 * Sdk
 *****************************************************************************/
/**
* @param[in] szLicense
* @param[in] szProducerSuffix

 * @return    \ref TRUE if the operation is successful; \ref FALSE if there is an error.
 * @note An error occurred when \ref FALSE was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_UnknownFormat if the format (version) of the <b>szLicense</b> argument is unknown.

 * - \ref ePtx_Error_Corrupt if the <b>szLicense</b> argument is not a correct license key

 * - \ref ePtx_Error_License if the <b>szLicense</b> argument can be read but the license check failed

 * - \ref ePtx_Error_Http A network error occurred.


 */
PDFTOOLS_TOOLBOX_EXPORT BOOL PDFTOOLS_TOOLBOX_CALL Ptx_Sdk_InitializeA(const char* szLicense,
                                                                       const char* szProducerSuffix);
/**
* @param[in] szLicense
* @param[in] szProducerSuffix

 * @return    \ref TRUE if the operation is successful; \ref FALSE if there is an error.
 * @note An error occurred when \ref FALSE was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_UnknownFormat if the format (version) of the <b>szLicense</b> argument is unknown.

 * - \ref ePtx_Error_Corrupt if the <b>szLicense</b> argument is not a correct license key

 * - \ref ePtx_Error_License if the <b>szLicense</b> argument can be read but the license check failed

 * - \ref ePtx_Error_Http A network error occurred.


 */
PDFTOOLS_TOOLBOX_EXPORT BOOL PDFTOOLS_TOOLBOX_CALL Ptx_Sdk_InitializeW(const WCHAR* szLicense,
                                                                       const WCHAR* szProducerSuffix);

/**
* @param[out] pBuffer Retrieved value.
To determine the required buffer size, the function has to be called with `NULL`.
The return value of this function specifies the buffer size.

* @param[in] nBufferSize The buffer size of the retrieved string `pBuffer`.


 * @return   The amount of data written to the buffer `pBuffer`.
   `0` if there is an error.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.

 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_Sdk_GetVersionA(char* pBuffer, size_t nBufferSize);
/**
* @param[out] pBuffer Retrieved value.
To determine the required buffer size, the function has to be called with `NULL`.
The return value of this function specifies the buffer size.

* @param[in] nBufferSize The buffer size of the retrieved string `pBuffer`.


 * @return   The amount of data written to the buffer `pBuffer`.
   `0` if there is an error.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.

 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_Sdk_GetVersionW(WCHAR* pBuffer, size_t nBufferSize);
/**
* @param[out] pBuffer Retrieved value.
To determine the required buffer size, the function has to be called with `NULL`.
The return value of this function specifies the buffer size.

* @param[in] nBufferSize The buffer size of the retrieved string `pBuffer`.


 * @return   The amount of data written to the buffer `pBuffer`.
   `0` if there is an error.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.

 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_Sdk_GetProducerFullNameA(char* pBuffer, size_t nBufferSize);
/**
* @param[out] pBuffer Retrieved value.
To determine the required buffer size, the function has to be called with `NULL`.
The return value of this function specifies the buffer size.

* @param[in] nBufferSize The buffer size of the retrieved string `pBuffer`.


 * @return   The amount of data written to the buffer `pBuffer`.
   `0` if there is an error.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.

 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_Sdk_GetProducerFullNameW(WCHAR* pBuffer, size_t nBufferSize);

/******************************************************************************
 * StringMap
 *****************************************************************************/
/**
 * @brief The number of key-value pairs in the map.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.


 * @return    May indicate an error in certain scenarios. For further information see the note section below.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState

 */
PDFTOOLS_TOOLBOX_EXPORT int PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetCount(TPtx_StringMap* pStringMap);
/**
 * @brief The number of key-value pairs in the map.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.


 * @return    May indicate an error in certain scenarios. For further information see the note section below.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState

 * @deprecated Deprecated in Version 1.1.0.
 */
PDFTOOLS_TOOLBOX_EXPORT int PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetSize(TPtx_StringMap* pStringMap);
/**
 * @brief Get the position of the first entry in the map.

The order of the entries is arbitrary and not significant.

If the returned position differs from \ref Ptx_StringMap_GetEnd,then the position can be used to retrieve the map entry
with \ref Ptx_StringMap_GetKey,  \ref Ptx_StringMap_GetValue.

Use \ref Ptx_StringMap_GetNext to get the position of the next entry.

* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.


 * @return    May indicate an error in certain scenarios. For further information see the note section below.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT int PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetBegin(TPtx_StringMap* pStringMap);
/**
 * @brief Get the end position of the map.

This position does not correspond to an actual entry in the map.

It must be used to determine whether the end of the map has been reached when using \ref Ptx_StringMap_GetBegin and \ref
Ptx_StringMap_GetNext.

* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.


 * @return    May indicate an error in certain scenarios. For further information see the note section below.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT int PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetEnd(TPtx_StringMap* pStringMap);
/**
 * @brief Get the position of the next entry in the map.

The order of the entries is arbitrary and not significant.

If the returned position differs from \ref Ptx_StringMap_GetEnd, then the position can be used to retrieve the map entry
with \ref Ptx_StringMap_GetKey and \ref Ptx_StringMap_GetValue.

* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] it

 * @return    May indicate an error in certain scenarios. For further information see the note section below.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT int PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetNext(TPtx_StringMap* pStringMap, int it);
/**
 * @brief Get the position of a key in the map.
If no error occurred, then the position can be used to get the corresponding value with \ref Ptx_StringMap_GetValue.

* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] szKey

 * @return    May indicate an error in certain scenarios. For further information see the note section below.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_NotFound
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT int PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetA(TPtx_StringMap* pStringMap, const char* szKey);
/**
 * @brief Get the position of a key in the map.
If no error occurred, then the position can be used to get the corresponding value with \ref Ptx_StringMap_GetValue.

* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] szKey

 * @return    May indicate an error in certain scenarios. For further information see the note section below.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_NotFound
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT int PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetW(TPtx_StringMap* pStringMap, const WCHAR* szKey);
/**
 * @brief Get the key of the entry given a position.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] it
* @param[out] pBuffer To determine the required buffer size, the function has to be called with `NULL`.
The return value of this function specifies the buffer size.

* @param[in] nBufferSize The buffer size of the retrieved string `pBuffer`.


 * @return   The amount of data written to the buffer `pBuffer`.
   `0` if there is an error.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetKeyA(TPtx_StringMap* pStringMap, int it,
                                                                           char* pBuffer, size_t nBufferSize);
/**
 * @brief Get the key of the entry given a position.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] it
* @param[out] pBuffer To determine the required buffer size, the function has to be called with `NULL`.
The return value of this function specifies the buffer size.

* @param[in] nBufferSize The buffer size of the retrieved string `pBuffer`.


 * @return   The amount of data written to the buffer `pBuffer`.
   `0` if there is an error.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetKeyW(TPtx_StringMap* pStringMap, int it,
                                                                           WCHAR* pBuffer, size_t nBufferSize);
/**
 * @brief Get the value of the entry given a position.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] it
* @param[out] pBuffer To determine the required buffer size, the function has to be called with `NULL`.
The return value of this function specifies the buffer size.

* @param[in] nBufferSize The buffer size of the retrieved string `pBuffer`.


 * @return   The amount of data written to the buffer `pBuffer`.
   `0` if there is an error.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetValueA(TPtx_StringMap* pStringMap, int it,
                                                                             char* pBuffer, size_t nBufferSize);
/**
 * @brief Get the value of the entry given a position.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] it
* @param[out] pBuffer To determine the required buffer size, the function has to be called with `NULL`.
The return value of this function specifies the buffer size.

* @param[in] nBufferSize The buffer size of the retrieved string `pBuffer`.


 * @return   The amount of data written to the buffer `pBuffer`.
   `0` if there is an error.
 * @note An error occurred when `0` was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT size_t PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_GetValueW(TPtx_StringMap* pStringMap, int it,
                                                                             WCHAR* pBuffer, size_t nBufferSize);
/**
 * @brief Set the value of an entry for a given key.
This operation invalidates all positions previously returned by‹pre›_‹map›_GetBegin, \ref Ptx_StringMap_GetEnd, \ref
Ptx_StringMap_GetNext, and \ref Ptx_StringMap_Get.

* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] szKey
* @param[in] szValue

 * @return    \ref TRUE if the operation is successful; \ref FALSE if there is an error.
 * @note An error occurred when \ref FALSE was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT BOOL PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_SetA(TPtx_StringMap* pStringMap, const char* szKey,
                                                                      const char* szValue);
/**
 * @brief Set the value of an entry for a given key.
This operation invalidates all positions previously returned by‹pre›_‹map›_GetBegin, \ref Ptx_StringMap_GetEnd, \ref
Ptx_StringMap_GetNext, and \ref Ptx_StringMap_Get.

* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] szKey
* @param[in] szValue

 * @return    \ref TRUE if the operation is successful; \ref FALSE if there is an error.
 * @note An error occurred when \ref FALSE was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT BOOL PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_SetW(TPtx_StringMap* pStringMap, const WCHAR* szKey,
                                                                      const WCHAR* szValue);
/**
 * @brief Set the value of the entry at a position in the map.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] it
* @param[in] szValue

 * @return    \ref TRUE if the operation is successful; \ref FALSE if there is an error.
 * @note An error occurred when \ref FALSE was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT BOOL PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_SetValueA(TPtx_StringMap* pStringMap, int it,
                                                                           const char* szValue);
/**
 * @brief Set the value of the entry at a position in the map.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] it
* @param[in] szValue

 * @return    \ref TRUE if the operation is successful; \ref FALSE if there is an error.
 * @note An error occurred when \ref FALSE was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT BOOL PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_SetValueW(TPtx_StringMap* pStringMap, int it,
                                                                           const WCHAR* szValue);
/**
 * @brief Remove all entries from the map.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.


 * @return    \ref TRUE if the operation is successful; \ref FALSE if there is an error.
 * @note An error occurred when \ref FALSE was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT BOOL PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_Clear(TPtx_StringMap* pStringMap);
/**
 * @brief Remove the entry at a position in the map.
* @param[in,out] pStringMap Acts as a handle to the native object of type \ref TPtx_StringMap.

* @param[in] it

 * @return    \ref TRUE if the operation is successful; \ref FALSE if there is an error.
 * @note An error occurred when \ref FALSE was returned. Retrieve specific error code by calling \ref Ptx_GetLastError.
 * Get the error message with \ref Ptx_GetLastErrorMessage.
 * Possible error codes:
 * - \ref ePtx_Error_IllegalState
 * - \ref ePtx_Error_IllegalArgument
 * - \ref ePtx_Error_UnsupportedOperation

 */
PDFTOOLS_TOOLBOX_EXPORT BOOL PDFTOOLS_TOOLBOX_CALL Ptx_StringMap_Remove(TPtx_StringMap* pStringMap, int it);

#ifdef __cplusplus
}
#endif

#endif /* PDFTOOLS_TOOLBOX_PTX_H__ */
