/******************************************************************************
 *
 * File:            PdfTools_Toolbox_Types.h
 *
 * Description:     Types definition for Toolbox SDK
 *
 * Author:          PDF Tools AG
 *
 * Copyright:       Copyright (C) 2024 - 2024 PDF Tools AG, Switzerland
 *                  All rights reserved.
 *
 * Notice:          By downloading and using this artifact, you accept PDF Tools AG's
 *                  [license agreement](https://www.pdf-tools.com/license-agreement/),
 *                  [privacy policy](https://www.pdf-tools.com/privacy-policy/),
 *                  and allow PDF Tools AG to track your usage data.
 *
 *****************************************************************************/

#ifndef PDFTOOLS_TOOLBOX_TYPES_H__
#define PDFTOOLS_TOOLBOX_TYPES_H__

#ifndef BOOL
#define BOOL  int
#define TRUE  1
#define FALSE 0
#endif

#ifdef __cplusplus
extern "C"
{
#endif

typedef enum TPtx_ErrorCode
{
    ePtx_Error_Success              = 0,
    ePtx_Error_UnsupportedOperation = 1,
    ePtx_Error_IllegalState         = 2,
    ePtx_Error_IllegalArgument      = 3,
    ePtx_Error_IO                   = 4,
    ePtx_Error_NotFound             = 5,
    ePtx_Error_Unknown              = 6,
    /**
     * @brief A generic error occurred.
     */
    ePtx_Error_Generic = 10,
    /**
     * @brief The license is not valid.
     */
    ePtx_Error_License = 12,
    /**
     * @brief The format is not known.
     */
    ePtx_Error_UnknownFormat = 15,
    /**
     * @brief The file is corrupt and cannot be opened.
     */
    ePtx_Error_Corrupt = 16,
    /**
     * @brief Invalid password specified.
     */
    ePtx_Error_Password = 17,
    /**
     * @brief The document has an invalid conformance level.
     */
    ePtx_Error_Conformance = 18,
    /**
     * @brief The document contains an unsupported feature.
     */
    ePtx_Error_UnsupportedFeature = 19,
    /**
     * @brief The specified item already exists.
     */
    ePtx_Error_Exists = 22,
    /**
     * @brief An error occurred while processing an HTTP request.
     */
    ePtx_Error_Http = 24,
} TPtx_ErrorCode;

/**
 */
typedef enum TPtxGeom_HorizontalAlignment
{
    /**
    Flush-left text alignment.

     */
    ePtxGeom_HorizontalAlignment_Left = 0,
    /**
    Centered text alignment.

     */
    ePtxGeom_HorizontalAlignment_Center = 1,
    /**
    Flush-right text alignment.

     */
    ePtxGeom_HorizontalAlignment_Right = 2,
} TPtxGeom_HorizontalAlignment;

/**
 */
typedef enum TPtxGeom_Rotation
{
    /**
     */
    ePtxGeom_Rotation_None = 0,
    /**
     */
    ePtxGeom_Rotation_Clockwise = 90,
    /**
     */
    ePtxGeom_Rotation_UpsideDown = 180,
    /**
     */
    ePtxGeom_Rotation_CounterClockwise = 270,
} TPtxGeom_Rotation;

/**
 */
typedef enum TPtxPdf_Permission
{
    /**
     * @brief No permission.
     */
    ePtxPdf_Permission_None = 0,
    /**
     * @brief Allow low resolution printing.
     */
    ePtxPdf_Permission_Print = 4,
    /**
     * @brief Allow changing the document.
     */
    ePtxPdf_Permission_Modify = 8,
    /**
     * @brief Allow content copying or extraction.
     */
    ePtxPdf_Permission_Copy = 16,
    /**
     * @brief Allow annotations.
     */
    ePtxPdf_Permission_Annotate = 32,
    /**
     * @brief Allow filling of form fields.
     */
    ePtxPdf_Permission_FillForms = 256,
    /**
     * @brief Allow support for disabilities.
     */
    ePtxPdf_Permission_SupportDisabilities = 512,
    /**
     * @brief Allow document assembly.
     */
    ePtxPdf_Permission_Assemble = 1024,
    /**
     * @brief Allow high resolution printing.
     */
    ePtxPdf_Permission_DigitalPrint = 2048,
    ePtxPdf_Permission_All          = 3900,
} TPtxPdf_Permission;

/**
 */
typedef enum TPtxPdf_Conformance
{
    /**
     * @brief PDF Version 1.0
     */
    ePtxPdf_Conformance_Pdf10 = 0x1000,
    /**
     * @brief PDF Version 1.1
     */
    ePtxPdf_Conformance_Pdf11 = 0x1100,
    /**
     * @brief PDF Version 1.2
     */
    ePtxPdf_Conformance_Pdf12 = 0x1200,
    /**
     * @brief PDF Version 1.3
     */
    ePtxPdf_Conformance_Pdf13 = 0x1300,
    /**
     * @brief PDF Version 1.4 (corresponds to Acrobat 5)
     */
    ePtxPdf_Conformance_Pdf14 = 0x1400,
    /**
     * @brief PDF Version 1.5
     */
    ePtxPdf_Conformance_Pdf15 = 0x1500,
    /**
     * @brief PDF Version 1.6 (corresponds to Acrobat 7)
     */
    ePtxPdf_Conformance_Pdf16 = 0x1600,
    /**
     * @brief PDF Version 1.7, ISO 32000-1
     */
    ePtxPdf_Conformance_Pdf17 = 0x1700,
    /**
     * @brief PDF Version 2.0, ISO 32000-2
     */
    ePtxPdf_Conformance_Pdf20 = 0x2000,
    /**
     * @brief PDF/A-1b, ISO 19005-1, level B conformance
     */
    ePtxPdf_Conformance_PdfA1B = 0x1401,
    /**
     * @brief PDF/A-1a, ISO 19005-1, level A conformance
     */
    ePtxPdf_Conformance_PdfA1A = 0x1402,
    /**
     * @brief PDF/A-2b, ISO 19005-2, level B conformance
     */
    ePtxPdf_Conformance_PdfA2B = 0x1701,
    /**
     * @brief PDF/A-2u, ISO 19005-2, level U conformance
     */
    ePtxPdf_Conformance_PdfA2U = 0x1702,
    /**
     * @brief PDF/A-2a, ISO 19005-2, level A conformance
     */
    ePtxPdf_Conformance_PdfA2A = 0x1703,
    /**
     * @brief PDF/A-3b, ISO 19005-3, level B conformance
     */
    ePtxPdf_Conformance_PdfA3B = 0x1711,
    /**
     * @brief PDF/A-3u, ISO 19005-3, level U conformance
     */
    ePtxPdf_Conformance_PdfA3U = 0x1712,
    /**
     * @brief PDF/A-3a, ISO 19005-3, level A conformance
     */
    ePtxPdf_Conformance_PdfA3A = 0x1713,
} TPtxPdf_Conformance;

/**
 */
typedef enum TPtxPdf_CopyStrategy
{
    /**
    The elements are copied as-is to the target document.

     */
    ePtxPdf_CopyStrategy_Copy = 1,
    /**
    The elements are removed but the visible representation is retained.

     */
    ePtxPdf_CopyStrategy_Flatten = 2,
    /**
    The elements are removed completely.

     */
    ePtxPdf_CopyStrategy_Remove = 3,
} TPtxPdf_CopyStrategy;

/**
 */
typedef enum TPtxPdf_RemovalStrategy
{
    /**
    The elements are removed but the visible representation is retained.

     */
    ePtxPdf_RemovalStrategy_Flatten = 2,
    /**
    The elements are removed completely.

     */
    ePtxPdf_RemovalStrategy_Remove = 3,
} TPtxPdf_RemovalStrategy;

/**
 */
typedef enum TPtxPdf_NameConflictResolution
{
    /**
    Elements with the same name are considered the same and are merged if possible.

     */
    ePtxPdf_NameConflictResolution_Merge = 1,
    /**
    Elements with the same name are considered different and the later occurrence is renamed.

     */
    ePtxPdf_NameConflictResolution_Rename = 2,
} TPtxPdf_NameConflictResolution;

/**
 */
typedef enum TPtxPdfContent_ProcessColorSpaceType
{
    /**
     */
    ePtxPdfContent_ProcessColorSpaceType_Gray = 1,
    /**
     */
    ePtxPdfContent_ProcessColorSpaceType_Rgb = 2,
    /**
     */
    ePtxPdfContent_ProcessColorSpaceType_Cmyk = 3,
} TPtxPdfContent_ProcessColorSpaceType;

/**
 */
typedef enum TPtxPdfContent_LineCapStyle
{
    /**
     */
    ePtxPdfContent_LineCapStyle_Butt = 0,
    /**
     */
    ePtxPdfContent_LineCapStyle_Round = 1,
    /**
     */
    ePtxPdfContent_LineCapStyle_Square = 2,
} TPtxPdfContent_LineCapStyle;

/**
 */
typedef enum TPtxPdfContent_LineJoinStyle
{
    /**
     */
    ePtxPdfContent_LineJoinStyle_Miter = 0,
    /**
     */
    ePtxPdfContent_LineJoinStyle_Round = 1,
    /**
     */
    ePtxPdfContent_LineJoinStyle_Bevel = 2,
} TPtxPdfContent_LineJoinStyle;

/**
 */
typedef enum TPtxPdfContent_InsideRule
{
    /**
     */
    ePtxPdfContent_InsideRule_NonzeroWindingNumber = 0,
    /**
     */
    ePtxPdfContent_InsideRule_EvenOdd = 1,
} TPtxPdfContent_InsideRule;

/**
 */
typedef enum TPtxPdfContent_BlendMode
{
    /**
     * @brief Selects the source color, ignoring the backdrop.
     */
    ePtxPdfContent_BlendMode_Normal = 0,
    /**
     * @brief Multiplies the backdrop and source color values

    The result color is always at least as dark as either of
    the two constituent colors.

    When working with additive colors,
    multiplying any color with black produces black while
    multiplying with white leaves the original color unchanged.

    For subtractive colors,
    the maximum tint value used for all colorants of
    the color space acts as black does for additive spaces.

    Painting successive overlapping objects with a color other
    than black or white produces progressively darker colors.

     */
    ePtxPdfContent_BlendMode_Multiply = 1,
    /**
     * @brief Multiplies the complements of the backdrop and source color values, then complements the result.

    The result color is always at least as light as either of
    the two constituent colors.

    When working with additive colors,
    screening any color with white produces white while
    screening with black leaves the original color unchanged.

    For subtractive colors,
    the maximum tint value of all colorants of
    the color space acts as black does for additive spaces.

    The effect is similar to projecting multiple photographic
    slides simultaneously onto a single screen.

     */
    ePtxPdfContent_BlendMode_Screen = 2,
    /**
     * @brief Selects the darker of the backdrop and source colors.
    The backdrop is replaced with the source where the source is darker;
    otherwise, it is left unchanged.

     */
    ePtxPdfContent_BlendMode_Darken = 4,
    /**
     * @brief Selects the lighter of the backdrop and source colors.
    The backdrop is replaced with the source where the source is lighter;
    otherwise, it is left unchanged.

     */
    ePtxPdfContent_BlendMode_Lighten = 5,
    /**
     * @brief Brightens the backdrop color to reflect the source color.
    Painting with black produces no change.

     */
    ePtxPdfContent_BlendMode_ColorDodge = 6,
    /**
     * @brief Darkens the backdrop color to reflect the source color.
    Painting with white produces no change.

     */
    ePtxPdfContent_BlendMode_ColorBurn = 7,
    /**
     * @brief Multiplies or screens the colors, depending on the source color value.
    The effect is similar to shining a harsh spotlight on the backdrop.

     */
    ePtxPdfContent_BlendMode_HardLight = 8,
    /**
     * @brief Darkens or lightens the colors, depending on the source color value.
    The effect is similar to shining a diffused spotlight on the backdrop.

     */
    ePtxPdfContent_BlendMode_SoftLight = 9,
    /**
     * @brief Multiplies or screens the colors, depending on the backdrop color value.
    Source colors overlay the backdrop while preserving its highlights and shadows.
    The backdrop color is not replaced but is mixed with the
    source color to reflect the lightness or darkness of the backdrop.

     */
    ePtxPdfContent_BlendMode_Overlay = 3,
    /**
     * @brief Subtracts the darker of the two constituent colors from the lighter color.

    Painting with white inverts the backdrop color;
    painting with black produces no change.

    For subtractive colors,
    the maximum tint value for all colourants of the color
    space acts as black does for additive spaces.

    This blend mode is not white-preserving.

     */
    ePtxPdfContent_BlendMode_Difference = 10,
    /**
     * @brief Produces an effect similar to that of the Difference mode but lower in contrast.

    Painting with white inverts the backdrop color;
    painting with black produces no change.

    For subtractive colors,
    the maximum tint value for all colourants of the color
    space acts as black does for additive spaces.

     */
    ePtxPdfContent_BlendMode_Exclusion = 11,
    /**
     * @brief Creates a color with the hue of the source color and the saturation and luminosity of the backdrop color.
    This blend mode is not separable.

     */
    ePtxPdfContent_BlendMode_Hue = 12,
    /**
     * @brief Creates a color with the saturation of the source color and the hue and luminosity of the backdrop color.

    Painting with this mode in an area of the backdrop
    that is a pure gray (no saturation) produces no change.

    This blend mode is not separable.

     */
    ePtxPdfContent_BlendMode_Saturation = 13,
    /**
     * @brief Creates a color with the hue and saturation of the source color and the luminosity of the backdrop color.

    This preserves the gray levels of the backdrop and is useful
    for coloring monochrome images or tinting color images.

    This blend mode is not separable.

     */
    ePtxPdfContent_BlendMode_Color = 14,
    /**
     * @brief Creates a color with the luminosity of the source color and the hue and saturation of the backdrop color.

    This produces an inverse effect to that of the \ref ePtxPdfContent_BlendMode_Color "" mode.

    This blend mode is not separable.

     */
    ePtxPdfContent_BlendMode_Luminosity = 15,
} TPtxPdfContent_BlendMode;

/**
Used to control the behavior of content extraction.
Groups in the content can either be extracted as \ref TPtxPdfContent_GroupElement ""s,
or their content can be unpacked, in which case groups' content elements are extracted as if not belonging to a group.

 */
typedef enum TPtxPdfContent_UngroupingSelection
{
    /**
    Groups are extracted as \ref TPtxPdfContent_GroupElement ""s

     */
    ePtxPdfContent_UngroupingSelection_None = 0,
    /**
    Un-grouping is restricted to those groups that can be un-grouped without visual loss.

     */
    ePtxPdfContent_UngroupingSelection_SafelyUngroupable = 1,
    /**
    Un-group all groups.
    Note that copying \ref TPtxPdfContent_ContentElement ""s with un-grouping set to \ref
    ePtxPdfContent_UngroupingSelection_All "" can alter content's visual appearance in the output document.

     */
    ePtxPdfContent_UngroupingSelection_All = 2,
} TPtxPdfContent_UngroupingSelection;

/**
Used to distinguish between horizontally and vertically written text.

 */
typedef enum TPtxPdfContent_WritingMode
{
    /**
    The writing direction is in positive x-direction.

     */
    ePtxPdfContent_WritingMode_Horizontal = 0,
    /**
    The writing direction is in negative y-direction.

     */
    ePtxPdfContent_WritingMode_Vertical = 1,
} TPtxPdfContent_WritingMode;

/**
Indicates the visual weight (degree of blackness or thickness of strokes) of the characters in the font.

 */
typedef enum TPtxPdfContent_FontWeight
{
    /**
     */
    ePtxPdfContent_FontWeight_Thin = 100,
    /**
     */
    ePtxPdfContent_FontWeight_ExtraLight = 200,
    /**
     */
    ePtxPdfContent_FontWeight_Light = 300,
    /**
     */
    ePtxPdfContent_FontWeight_Normal = 400,
    /**
     */
    ePtxPdfContent_FontWeight_Medium = 500,
    /**
     */
    ePtxPdfContent_FontWeight_SemiBold = 600,
    /**
     */
    ePtxPdfContent_FontWeight_Bold = 700,
    /**
     */
    ePtxPdfContent_FontWeight_ExtraBold = 800,
    /**
     */
    ePtxPdfContent_FontWeight_Black = 900,
} TPtxPdfContent_FontWeight;

/**
Used to distinguish between linear (line) and cubic (Bezier curve) path segments.

 */
typedef enum TPtxPdfContent_PathSegmentType
{
    /**
    A line segment from the current point to the end point.

     */
    ePtxPdfContent_PathSegmentType_Linear = 0,
    /**
    A cubic Bezier curve segment (with two control points) from the current point to the end point.

     */
    ePtxPdfContent_PathSegmentType_Cubic = 1,
} TPtxPdfContent_PathSegmentType;

/**
Denotes the type of the image.

 */
typedef enum TPtxPdfContent_ImageType
{
    /**
     */
    ePtxPdfContent_ImageType_Bmp = 0,
    /**
     */
    ePtxPdfContent_ImageType_Jpeg = 1,
    /**
     */
    ePtxPdfContent_ImageType_Jpeg2000 = 2,
    /**
     */
    ePtxPdfContent_ImageType_Jbig2 = 3,
    /**
     */
    ePtxPdfContent_ImageType_Png = 4,
    /**
     */
    ePtxPdfContent_ImageType_Gif = 5,
    /**
     */
    ePtxPdfContent_ImageType_Tiff = 6,
} TPtxPdfContent_ImageType;

/**
 */
typedef enum TPtxPdfForms_FormFieldCopyStrategy
{
    /**
    The elements are copied as-is to the target document.

     */
    ePtxPdfForms_FormFieldCopyStrategy_Copy = 1,
    /**
    The elements are removed but the visible representation is retained.

     */
    ePtxPdfForms_FormFieldCopyStrategy_Flatten = 2,
    /**
    The elements are removed completely.

     */
    ePtxPdfForms_FormFieldCopyStrategy_Remove = 3,
    /**
    Copy widgets that belong to form fields copied previously with \ref PtxPdfForms_FieldNode_Copy "".
    Any changes made to copied form fields are reflected in the widgets.

     */
    ePtxPdfForms_FormFieldCopyStrategy_CopyAndUpdateWidgets = 4,
} TPtxPdfForms_FormFieldCopyStrategy;

/**
 */
typedef enum TPtxPdfForms_MdpPermissions
{
    /**
    No changes to the document shall be permitted;
    any change to the document shall invalidate the signature.

     */
    ePtxPdfForms_MdpPermissions_NoChanges = 1,
    /**
    Permitted changes shall be filling in forms, instantiating page templates, and signing;
    other changes shall invalidate the signature.

     */
    ePtxPdfForms_MdpPermissions_FormFilling = 2,
    /**
    Permitted changes shall be the same as for \ref ePtxPdfForms_MdpPermissions_FormFilling "",
    as well as annotation creation, deletion, and modification;
    other changes shall invalidate the signature.

     */
    ePtxPdfForms_MdpPermissions_Annotate = 3,
} TPtxPdfForms_MdpPermissions;

/**
Specifies an informational side pane in a viewer used for document navigation or displaying document wide information.

 */
typedef enum TPtxPdfNav_ViewerNavigationPane
{
    /**
     */
    ePtxPdfNav_ViewerNavigationPane_None = 0,
    /**
     */
    ePtxPdfNav_ViewerNavigationPane_Outlines = 1,
    /**
     */
    ePtxPdfNav_ViewerNavigationPane_Thumbnails = 2,
    /**
     */
    ePtxPdfNav_ViewerNavigationPane_Layers = 3,
    /**
     */
    ePtxPdfNav_ViewerNavigationPane_EmbeddedFiles = 4,
} TPtxPdfNav_ViewerNavigationPane;

/**
Specifies the horizontal arrangement for displaying pages.

 */
typedef enum TPtxPdfNav_PageLayout
{
    /**
    Displays one page.

     */
    ePtxPdfNav_PageLayout_OnePage = 0,
    /**
    Displays two pages side by side.

     */
    ePtxPdfNav_PageLayout_TwoPage = 1,
    /**
    Use \ref ePtxPdfNav_PageLayout_OnePage "" display for the first page and \ref ePtxPdfNav_PageLayout_TwoPage ""
    display for the remaining pages.

     */
    ePtxPdfNav_PageLayout_TwoPageFirstPageSingle = 2,
} TPtxPdfNav_PageLayout;

/**
 */
typedef enum TPtxPdfNav_NamedDestinationCopyStrategy
{
    /**
     * @brief Copy named destinations
    Named destinations are copyied as-is.

     */
    ePtxPdfNav_NamedDestinationCopyStrategy_Copy = 1,
    /**
     * @brief Resolve named destinations
    Named destinations are resolved and converted to direct destinations.

     */
    ePtxPdfNav_NamedDestinationCopyStrategy_Resolve = 2,
} TPtxPdfNav_NamedDestinationCopyStrategy;

/**
Specifies the type of line termination for line and poly-line annotations.

 */
typedef enum TPtxPdfAnnots_LineEnding
{
    /**
     */
    ePtxPdfAnnots_LineEnding_None = 0,
    /**
     */
    ePtxPdfAnnots_LineEnding_OpenArrow = 1,
    /**
     */
    ePtxPdfAnnots_LineEnding_ClosedArrow = 2,
    /**
     */
    ePtxPdfAnnots_LineEnding_Square = 3,
    /**
     */
    ePtxPdfAnnots_LineEnding_Circle = 4,
    /**
     */
    ePtxPdfAnnots_LineEnding_Diamond = 5,
    /**
     */
    ePtxPdfAnnots_LineEnding_Butt = 6,
    /**
     */
    ePtxPdfAnnots_LineEnding_OpenArrowTail = 7,
    /**
     */
    ePtxPdfAnnots_LineEnding_ClosedArrowTail = 8,
    /**
     */
    ePtxPdfAnnots_LineEnding_Slash = 9,
} TPtxPdfAnnots_LineEnding;

/**
Specifies the text displayed for predefined \ref TPtxPdfAnnots_TextStamp ""s.

 */
typedef enum TPtxPdfAnnots_TextStampType
{
    /**
     */
    ePtxPdfAnnots_TextStampType_Approved = 0,
    /**
     */
    ePtxPdfAnnots_TextStampType_Experimental = 1,
    /**
     */
    ePtxPdfAnnots_TextStampType_NotApproved = 2,
    /**
     */
    ePtxPdfAnnots_TextStampType_AsIs = 3,
    /**
     */
    ePtxPdfAnnots_TextStampType_Expired = 4,
    /**
     */
    ePtxPdfAnnots_TextStampType_NotForPublicRelease = 5,
    /**
     */
    ePtxPdfAnnots_TextStampType_Confidential = 6,
    /**
     */
    ePtxPdfAnnots_TextStampType_Final = 7,
    /**
     */
    ePtxPdfAnnots_TextStampType_Sold = 8,
    /**
     */
    ePtxPdfAnnots_TextStampType_Departmental = 9,
    /**
     */
    ePtxPdfAnnots_TextStampType_ForComment = 10,
    /**
     */
    ePtxPdfAnnots_TextStampType_TopSecret = 11,
    /**
     */
    ePtxPdfAnnots_TextStampType_Draft = 12,
    /**
     */
    ePtxPdfAnnots_TextStampType_ForPublicRelease = 13,
    /**
     */
    ePtxPdfAnnots_TextStampType_CustomStampText = 127,
} TPtxPdfAnnots_TextStampType;

/**
Specifies the type of icon displayed on a page for a \ref TPtxPdfAnnots_FileAttachment "".

 */
typedef enum TPtxPdfAnnots_FileAttachmentIcon
{
    /**
     */
    ePtxPdfAnnots_FileAttachmentIcon_Graph = 0,
    /**
     */
    ePtxPdfAnnots_FileAttachmentIcon_PushPin = 1,
    /**
     */
    ePtxPdfAnnots_FileAttachmentIcon_Paperclip = 2,
    /**
     */
    ePtxPdfAnnots_FileAttachmentIcon_Tag = 3,
    /**
     */
    ePtxPdfAnnots_FileAttachmentIcon_CustomIcon = 127,
} TPtxPdfAnnots_FileAttachmentIcon;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfContent_ColorSpace
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfContent_ColorSpace. The other items refer to
 * the derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfContent_ColorSpace*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfContent_ColorSpace_GetType function of
 * the parent class: `TPtxPdfContent_ColorSpaceType iChildType = PtxPdfContent_ColorSpace_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfContent_ColorSpaceType
{
    ePtxPdfContent_ColorSpaceType_ColorSpace,
    ePtxPdfContent_ColorSpaceType_DeviceGrayColorSpace,
    ePtxPdfContent_ColorSpaceType_DeviceRgbColorSpace,
    ePtxPdfContent_ColorSpaceType_DeviceCmykColorSpace,
    ePtxPdfContent_ColorSpaceType_CalibratedGrayColorSpace,
    ePtxPdfContent_ColorSpaceType_CalibratedRgbColorSpace,
    ePtxPdfContent_ColorSpaceType_LabColorSpace,
    ePtxPdfContent_ColorSpaceType_IccBasedColorSpace,
    ePtxPdfContent_ColorSpaceType_IndexedColorSpace,
    ePtxPdfContent_ColorSpaceType_SeparationColorSpace,
    ePtxPdfContent_ColorSpaceType_NChannelColorSpace
} TPtxPdfContent_ColorSpaceType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfContent_ContentElement
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfContent_ContentElement. The other items refer
 * to the derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfContent_ContentElement*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfContent_ContentElement_GetType function
 * of the parent class: `TPtxPdfContent_ContentElementType iChildType =
 * PtxPdfContent_ContentElement_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfContent_ContentElementType
{
    ePtxPdfContent_ContentElementType_ContentElement,
    ePtxPdfContent_ContentElementType_TextElement,
    ePtxPdfContent_ContentElementType_GroupElement,
    ePtxPdfContent_ContentElementType_PathElement,
    ePtxPdfContent_ContentElementType_ImageElement,
    ePtxPdfContent_ContentElementType_ImageMaskElement,
    ePtxPdfContent_ContentElementType_ShadingElement
} TPtxPdfContent_ContentElementType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfForms_FieldNode
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfForms_FieldNode. The other items refer to the
 * derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfForms_FieldNode*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfForms_FieldNode_GetType function of the
 * parent class: `TPtxPdfForms_FieldNodeType iChildType = PtxPdfForms_FieldNode_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfForms_FieldNodeType
{
    ePtxPdfForms_FieldNodeType_FieldNode,
    ePtxPdfForms_FieldNodeType_SubForm,
    ePtxPdfForms_FieldNodeType_Field,
    ePtxPdfForms_FieldNodeType_TextField,
    ePtxPdfForms_FieldNodeType_GeneralTextField,
    ePtxPdfForms_FieldNodeType_CombTextField,
    ePtxPdfForms_FieldNodeType_PushButton,
    ePtxPdfForms_FieldNodeType_CheckBox,
    ePtxPdfForms_FieldNodeType_RadioButtonGroup,
    ePtxPdfForms_FieldNodeType_ChoiceField,
    ePtxPdfForms_FieldNodeType_ListBox,
    ePtxPdfForms_FieldNodeType_ComboBox
} TPtxPdfForms_FieldNodeType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfForms_Field
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfForms_Field. The other items refer to the
 * derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfForms_Field*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfForms_Field_GetType function of the
 * parent class: `TPtxPdfForms_FieldType iChildType = PtxPdfForms_Field_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfForms_FieldType
{
    ePtxPdfForms_FieldType_Field,
    ePtxPdfForms_FieldType_TextField,
    ePtxPdfForms_FieldType_GeneralTextField,
    ePtxPdfForms_FieldType_CombTextField,
    ePtxPdfForms_FieldType_PushButton,
    ePtxPdfForms_FieldType_CheckBox,
    ePtxPdfForms_FieldType_RadioButtonGroup,
    ePtxPdfForms_FieldType_ChoiceField,
    ePtxPdfForms_FieldType_ListBox,
    ePtxPdfForms_FieldType_ComboBox
} TPtxPdfForms_FieldType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfForms_TextField
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfForms_TextField. The other items refer to the
 * derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfForms_TextField*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfForms_TextField_GetType function of the
 * parent class: `TPtxPdfForms_TextFieldType iChildType = PtxPdfForms_TextField_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfForms_TextFieldType
{
    ePtxPdfForms_TextFieldType_TextField,
    ePtxPdfForms_TextFieldType_GeneralTextField,
    ePtxPdfForms_TextFieldType_CombTextField
} TPtxPdfForms_TextFieldType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfForms_ChoiceField
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfForms_ChoiceField. The other items refer to the
 * derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfForms_ChoiceField*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfForms_ChoiceField_GetType function of the
 * parent class: `TPtxPdfForms_ChoiceFieldType iChildType = PtxPdfForms_ChoiceField_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfForms_ChoiceFieldType
{
    ePtxPdfForms_ChoiceFieldType_ChoiceField,
    ePtxPdfForms_ChoiceFieldType_ListBox,
    ePtxPdfForms_ChoiceFieldType_ComboBox
} TPtxPdfForms_ChoiceFieldType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfForms_SignatureField
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfForms_SignatureField. The other items refer to
 * the derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfForms_SignatureField*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfForms_SignatureField_GetType function of
 * the parent class: `TPtxPdfForms_SignatureFieldType iChildType =
 * PtxPdfForms_SignatureField_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfForms_SignatureFieldType
{
    ePtxPdfForms_SignatureFieldType_SignatureField,
    ePtxPdfForms_SignatureFieldType_SignedSignatureField,
    ePtxPdfForms_SignatureFieldType_Signature,
    ePtxPdfForms_SignatureFieldType_DocumentSignature,
    ePtxPdfForms_SignatureFieldType_DocMdpSignature,
    ePtxPdfForms_SignatureFieldType_DocumentTimeStamp
} TPtxPdfForms_SignatureFieldType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfForms_SignedSignatureField
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfForms_SignedSignatureField. The other items
 * refer to the derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfForms_SignedSignatureField*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfForms_SignedSignatureField_GetType
 * function of the parent class: `TPtxPdfForms_SignedSignatureFieldType iChildType =
 * PtxPdfForms_SignedSignatureField_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfForms_SignedSignatureFieldType
{
    ePtxPdfForms_SignedSignatureFieldType_SignedSignatureField,
    ePtxPdfForms_SignedSignatureFieldType_Signature,
    ePtxPdfForms_SignedSignatureFieldType_DocumentSignature,
    ePtxPdfForms_SignedSignatureFieldType_DocMdpSignature,
    ePtxPdfForms_SignedSignatureFieldType_DocumentTimeStamp
} TPtxPdfForms_SignedSignatureFieldType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfForms_Signature
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfForms_Signature. The other items refer to the
 * derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfForms_Signature*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfForms_Signature_GetType function of the
 * parent class: `TPtxPdfForms_SignatureType iChildType = PtxPdfForms_Signature_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfForms_SignatureType
{
    ePtxPdfForms_SignatureType_Signature,
    ePtxPdfForms_SignatureType_DocumentSignature,
    ePtxPdfForms_SignatureType_DocMdpSignature
} TPtxPdfForms_SignatureType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfNav_Destination
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfNav_Destination. The other items refer to the
 * derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfNav_Destination*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfNav_Destination_GetType function of the
 * parent class: `TPtxPdfNav_DestinationType iChildType = PtxPdfNav_Destination_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfNav_DestinationType
{
    ePtxPdfNav_DestinationType_Destination,
    ePtxPdfNav_DestinationType_NamedDestination,
    ePtxPdfNav_DestinationType_DirectDestination,
    ePtxPdfNav_DestinationType_LocationZoomDestination,
    ePtxPdfNav_DestinationType_FitPageDestination,
    ePtxPdfNav_DestinationType_FitWidthDestination,
    ePtxPdfNav_DestinationType_FitHeightDestination,
    ePtxPdfNav_DestinationType_FitRectangleDestination
} TPtxPdfNav_DestinationType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfNav_DirectDestination
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfNav_DirectDestination. The other items refer to
 * the derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfNav_DirectDestination*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfNav_DirectDestination_GetType function of
 * the parent class: `TPtxPdfNav_DirectDestinationType iChildType =
 * PtxPdfNav_DirectDestination_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfNav_DirectDestinationType
{
    ePtxPdfNav_DirectDestinationType_DirectDestination,
    ePtxPdfNav_DirectDestinationType_LocationZoomDestination,
    ePtxPdfNav_DirectDestinationType_FitPageDestination,
    ePtxPdfNav_DirectDestinationType_FitWidthDestination,
    ePtxPdfNav_DirectDestinationType_FitHeightDestination,
    ePtxPdfNav_DirectDestinationType_FitRectangleDestination
} TPtxPdfNav_DirectDestinationType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfNav_Link
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfNav_Link. The other items refer to the derived
 * types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfNav_Link*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfNav_Link_GetType function of the parent
 * class: `TPtxPdfNav_LinkType iChildType = PtxPdfNav_Link_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfNav_LinkType
{
    ePtxPdfNav_LinkType_Link,
    ePtxPdfNav_LinkType_InternalLink,
    ePtxPdfNav_LinkType_WebLink,
    ePtxPdfNav_LinkType_EmbeddedPdfLink
} TPtxPdfNav_LinkType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfAnnots_Annotation
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfAnnots_Annotation. The other items refer to the
 * derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfAnnots_Annotation*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfAnnots_Annotation_GetType function of the
 * parent class: `TPtxPdfAnnots_AnnotationType iChildType = PtxPdfAnnots_Annotation_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfAnnots_AnnotationType
{
    ePtxPdfAnnots_AnnotationType_Annotation,
    ePtxPdfAnnots_AnnotationType_MarkupAnnotation,
    ePtxPdfAnnots_AnnotationType_StickyNote,
    ePtxPdfAnnots_AnnotationType_FileAttachment,
    ePtxPdfAnnots_AnnotationType_Stamp,
    ePtxPdfAnnots_AnnotationType_TextStamp,
    ePtxPdfAnnots_AnnotationType_CustomStamp,
    ePtxPdfAnnots_AnnotationType_FreeText,
    ePtxPdfAnnots_AnnotationType_DrawingAnnotation,
    ePtxPdfAnnots_AnnotationType_LineAnnotation,
    ePtxPdfAnnots_AnnotationType_InkAnnotation,
    ePtxPdfAnnots_AnnotationType_PolyLineAnnotation,
    ePtxPdfAnnots_AnnotationType_PolygonAnnotation,
    ePtxPdfAnnots_AnnotationType_RectangleAnnotation,
    ePtxPdfAnnots_AnnotationType_EllipseAnnotation,
    ePtxPdfAnnots_AnnotationType_TextMarkup,
    ePtxPdfAnnots_AnnotationType_Highlight,
    ePtxPdfAnnots_AnnotationType_Underline,
    ePtxPdfAnnots_AnnotationType_StrikeThrough,
    ePtxPdfAnnots_AnnotationType_Squiggly,
    ePtxPdfAnnots_AnnotationType_TextInsert
} TPtxPdfAnnots_AnnotationType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfAnnots_MarkupAnnotation
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfAnnots_MarkupAnnotation. The other items refer
 * to the derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfAnnots_MarkupAnnotation*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfAnnots_MarkupAnnotation_GetType function
 * of the parent class: `TPtxPdfAnnots_MarkupAnnotationType iChildType =
 * PtxPdfAnnots_MarkupAnnotation_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfAnnots_MarkupAnnotationType
{
    ePtxPdfAnnots_MarkupAnnotationType_MarkupAnnotation,
    ePtxPdfAnnots_MarkupAnnotationType_StickyNote,
    ePtxPdfAnnots_MarkupAnnotationType_FileAttachment,
    ePtxPdfAnnots_MarkupAnnotationType_Stamp,
    ePtxPdfAnnots_MarkupAnnotationType_TextStamp,
    ePtxPdfAnnots_MarkupAnnotationType_CustomStamp,
    ePtxPdfAnnots_MarkupAnnotationType_FreeText,
    ePtxPdfAnnots_MarkupAnnotationType_DrawingAnnotation,
    ePtxPdfAnnots_MarkupAnnotationType_LineAnnotation,
    ePtxPdfAnnots_MarkupAnnotationType_InkAnnotation,
    ePtxPdfAnnots_MarkupAnnotationType_PolyLineAnnotation,
    ePtxPdfAnnots_MarkupAnnotationType_PolygonAnnotation,
    ePtxPdfAnnots_MarkupAnnotationType_RectangleAnnotation,
    ePtxPdfAnnots_MarkupAnnotationType_EllipseAnnotation,
    ePtxPdfAnnots_MarkupAnnotationType_TextMarkup,
    ePtxPdfAnnots_MarkupAnnotationType_Highlight,
    ePtxPdfAnnots_MarkupAnnotationType_Underline,
    ePtxPdfAnnots_MarkupAnnotationType_StrikeThrough,
    ePtxPdfAnnots_MarkupAnnotationType_Squiggly,
    ePtxPdfAnnots_MarkupAnnotationType_TextInsert
} TPtxPdfAnnots_MarkupAnnotationType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfAnnots_Stamp
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfAnnots_Stamp. The other items refer to the
 * derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfAnnots_Stamp*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfAnnots_Stamp_GetType function of the
 * parent class: `TPtxPdfAnnots_StampType iChildType = PtxPdfAnnots_Stamp_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfAnnots_StampType
{
    ePtxPdfAnnots_StampType_Stamp,
    ePtxPdfAnnots_StampType_TextStamp,
    ePtxPdfAnnots_StampType_CustomStamp
} TPtxPdfAnnots_StampType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfAnnots_DrawingAnnotation
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfAnnots_DrawingAnnotation. The other items refer
 * to the derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfAnnots_DrawingAnnotation*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfAnnots_DrawingAnnotation_GetType function
 * of the parent class: `TPtxPdfAnnots_DrawingAnnotationType iChildType =
 * PtxPdfAnnots_DrawingAnnotation_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfAnnots_DrawingAnnotationType
{
    ePtxPdfAnnots_DrawingAnnotationType_DrawingAnnotation,
    ePtxPdfAnnots_DrawingAnnotationType_LineAnnotation,
    ePtxPdfAnnots_DrawingAnnotationType_InkAnnotation,
    ePtxPdfAnnots_DrawingAnnotationType_PolyLineAnnotation,
    ePtxPdfAnnots_DrawingAnnotationType_PolygonAnnotation,
    ePtxPdfAnnots_DrawingAnnotationType_RectangleAnnotation,
    ePtxPdfAnnots_DrawingAnnotationType_EllipseAnnotation
} TPtxPdfAnnots_DrawingAnnotationType;

/**
 * @brief Type and subtype enumeration of \ref TPtxPdfAnnots_TextMarkup
 *
 * This SDK uses a class hierarchy, where child types can be derived from parent types.
 * The first item of the enumeration refers to the base type \ref TPtxPdfAnnots_TextMarkup. The other items refer to the
 * derived types.
 *
 * Downcasting may be necessary. For example, to call the functions of an object’s parent class.
 * In this case, a handle of the child type can be casted using a simple C-style cast:
 * `(TPtxPdfAnnots_TextMarkup*)pChildTypeHandle`.
 *
 * Upcasting is also possible using a C-style cast.
 * Before casting, determine the child type of the handle using the \ref PtxPdfAnnots_TextMarkup_GetType function of the
 * parent class: `TPtxPdfAnnots_TextMarkupType iChildType = PtxPdfAnnots_TextMarkup_GetType(pParentTypeHandle)`.
 */
typedef enum TPtxPdfAnnots_TextMarkupType
{
    ePtxPdfAnnots_TextMarkupType_TextMarkup,
    ePtxPdfAnnots_TextMarkupType_Highlight,
    ePtxPdfAnnots_TextMarkupType_Underline,
    ePtxPdfAnnots_TextMarkupType_StrikeThrough,
    ePtxPdfAnnots_TextMarkupType_Squiggly
} TPtxPdfAnnots_TextMarkupType;

/**
 * \class TPtx_Sdk
 */
typedef struct TPtx_Sdk TPtx_Sdk;
/**
 * \class TPtx_StringMap
 */
typedef struct TPtx_StringMap TPtx_StringMap;
/**
 * \class TPtxGeomReal_QuadrilateralList
 */
typedef struct TPtxGeomReal_QuadrilateralList TPtxGeomReal_QuadrilateralList;
/**
 * \class TPtxPdf_PageCopyOptions
 */
typedef struct TPtxPdf_PageCopyOptions TPtxPdf_PageCopyOptions;
/**
 * \class TPtxPdf_Encryption
 */
typedef struct TPtxPdf_Encryption TPtxPdf_Encryption;
/**
 * \class TPtxPdf_PageList
 */
typedef struct TPtxPdf_PageList TPtxPdf_PageList;
/**
 * \class TPtxPdf_FileReferenceList
 */
typedef struct TPtxPdf_FileReferenceList TPtxPdf_FileReferenceList;
/**
 * \class TPtxPdf_Document
 */
typedef struct TPtxPdf_Document TPtxPdf_Document;
/**
 * \class TPtxPdf_Page
 */
typedef struct TPtxPdf_Page TPtxPdf_Page;
/**
 * \class TPtxPdf_Metadata

Represents the metadata of a document or an object in a document.

For document level metadata,
all changes are reflected in both,
XMP metadata and document info dictionary depending on the conformance
of the document.

 */
typedef struct TPtxPdf_Metadata TPtxPdf_Metadata;
/**
 * \class TPtxPdf_FileReference
 * @brief Description of a file
A file description is used for embedded files.

 */
typedef struct TPtxPdf_FileReference TPtxPdf_FileReference;
/**
 * \class TPtxPdfContent_Transparency
 */
typedef struct TPtxPdfContent_Transparency TPtxPdfContent_Transparency;
/**
 * \class TPtxPdfContent_Stroke
 */
typedef struct TPtxPdfContent_Stroke TPtxPdfContent_Stroke;
/**
 * \class TPtxPdfContent_Fill
 */
typedef struct TPtxPdfContent_Fill TPtxPdfContent_Fill;
/**
 * \class TPtxPdfContent_Image
 */
typedef struct TPtxPdfContent_Image TPtxPdfContent_Image;
/**
 * \class TPtxPdfContent_ImageMask
 */
typedef struct TPtxPdfContent_ImageMask TPtxPdfContent_ImageMask;
/**
 * \class TPtxPdfContent_Font
 */
typedef struct TPtxPdfContent_Font TPtxPdfContent_Font;
/**
 * \class TPtxPdfContent_Group
 */
typedef struct TPtxPdfContent_Group TPtxPdfContent_Group;
/**
 * \class TPtxPdfContent_ColorSpace
 */
typedef struct TPtxPdfContent_ColorSpace TPtxPdfContent_ColorSpace;
/**
 * \class TPtxPdfContent_DeviceGrayColorSpace
 */
typedef struct TPtxPdfContent_DeviceGrayColorSpace TPtxPdfContent_DeviceGrayColorSpace;
/**
 * \class TPtxPdfContent_DeviceRgbColorSpace
 */
typedef struct TPtxPdfContent_DeviceRgbColorSpace TPtxPdfContent_DeviceRgbColorSpace;
/**
 * \class TPtxPdfContent_DeviceCmykColorSpace
 */
typedef struct TPtxPdfContent_DeviceCmykColorSpace TPtxPdfContent_DeviceCmykColorSpace;
/**
 * \class TPtxPdfContent_CalibratedGrayColorSpace
 */
typedef struct TPtxPdfContent_CalibratedGrayColorSpace TPtxPdfContent_CalibratedGrayColorSpace;
/**
 * \class TPtxPdfContent_CalibratedRgbColorSpace
 */
typedef struct TPtxPdfContent_CalibratedRgbColorSpace TPtxPdfContent_CalibratedRgbColorSpace;
/**
 * \class TPtxPdfContent_LabColorSpace
 */
typedef struct TPtxPdfContent_LabColorSpace TPtxPdfContent_LabColorSpace;
/**
 * \class TPtxPdfContent_IccBasedColorSpace
 */
typedef struct TPtxPdfContent_IccBasedColorSpace TPtxPdfContent_IccBasedColorSpace;
/**
 * \class TPtxPdfContent_IndexedColorSpace
 */
typedef struct TPtxPdfContent_IndexedColorSpace TPtxPdfContent_IndexedColorSpace;
/**
 * \class TPtxPdfContent_SeparationColorSpace
 */
typedef struct TPtxPdfContent_SeparationColorSpace TPtxPdfContent_SeparationColorSpace;
/**
 * \class TPtxPdfContent_NChannelColorSpace
 */
typedef struct TPtxPdfContent_NChannelColorSpace TPtxPdfContent_NChannelColorSpace;
/**
 * \class TPtxPdfContent_Subpath
 * @brief A disconnected subpath.
A container for connected path segments.

 */
typedef struct TPtxPdfContent_Subpath TPtxPdfContent_Subpath;
/**
 * \class TPtxPdfContent_Path
 * @brief Paths define shapes, trajectories, and regions of all sorts.
A path is made up of one or more disconnected subpaths, each comprising a sequence of connected segments.
The topology of the path is unrestricted: it can be concave or convex, can contain multiple subpaths representing
disjoint areas, and can intersect itself in arbitrary ways.

 */
typedef struct TPtxPdfContent_Path TPtxPdfContent_Path;
/**
 * \class TPtxPdfContent_PathIterator
 */
typedef struct TPtxPdfContent_PathIterator TPtxPdfContent_PathIterator;
/**
 * \class TPtxPdfContent_ContentGenerator
 */
typedef struct TPtxPdfContent_ContentGenerator TPtxPdfContent_ContentGenerator;
/**
 * \class TPtxPdfContent_PathGenerator
 */
typedef struct TPtxPdfContent_PathGenerator TPtxPdfContent_PathGenerator;
/**
 * \class TPtxPdfContent_TextGenerator
 */
typedef struct TPtxPdfContent_TextGenerator TPtxPdfContent_TextGenerator;
/**
 * \class TPtxPdfContent_Content
 * @brief Represents the content of a page or a group.
The class has no methods on its own,
but can be modified with a \ref TPtxPdfContent_ContentGenerator "" or extracted with
a \ref TPtxPdfContent_ContentExtractor "".

 */
typedef struct TPtxPdfContent_Content TPtxPdfContent_Content;
/**
 * \class TPtxPdfContent_Paint
 */
typedef struct TPtxPdfContent_Paint TPtxPdfContent_Paint;
/**
 * \class TPtxPdfContent_Glyph
 */
typedef struct TPtxPdfContent_Glyph TPtxPdfContent_Glyph;
/**
 * \class TPtxPdfContent_TextFragment
 * @brief Text Fragment

A \ref TPtxPdfContent_TextElement "" contains an arbitrary number of text fragments.
Text can be partitioned arbibrarily into fragments without respecting word boundaries or reading order.

A text fragment provides iteration over all contained \ref TPtxPdfContent_Glyph ""s.
Removing, clearing, adding, and sub-ranges are not supported.
While iterating, a \ref ePtx_Error_Corrupt "" may be generated if the text fragment contains glyphs
with inconsistent Unicode information.

 */
typedef struct TPtxPdfContent_TextFragment TPtxPdfContent_TextFragment;
/**
 * \class TPtxPdfContent_Text
 */
typedef struct TPtxPdfContent_Text TPtxPdfContent_Text;
/**
 * \class TPtxPdfContent_ContentElement
 */
typedef struct TPtxPdfContent_ContentElement TPtxPdfContent_ContentElement;
/**
 * \class TPtxPdfContent_TextElement
 */
typedef struct TPtxPdfContent_TextElement TPtxPdfContent_TextElement;
/**
 * \class TPtxPdfContent_GroupElement
 */
typedef struct TPtxPdfContent_GroupElement TPtxPdfContent_GroupElement;
/**
 * \class TPtxPdfContent_PathElement
 */
typedef struct TPtxPdfContent_PathElement TPtxPdfContent_PathElement;
/**
 * \class TPtxPdfContent_ImageElement
 */
typedef struct TPtxPdfContent_ImageElement TPtxPdfContent_ImageElement;
/**
 * \class TPtxPdfContent_ImageMaskElement
 */
typedef struct TPtxPdfContent_ImageMaskElement TPtxPdfContent_ImageMaskElement;
/**
 * \class TPtxPdfContent_ShadingElement
 */
typedef struct TPtxPdfContent_ShadingElement TPtxPdfContent_ShadingElement;
/**
 * \class TPtxPdfContent_ContentExtractor
 */
typedef struct TPtxPdfContent_ContentExtractor TPtxPdfContent_ContentExtractor;
/**
 * \class TPtxPdfContent_ContentExtractorIterator
 */
typedef struct TPtxPdfContent_ContentExtractorIterator TPtxPdfContent_ContentExtractorIterator;
/**
 * \class TPtxPdfForms_FieldNodeMap
 */
typedef struct TPtxPdfForms_FieldNodeMap TPtxPdfForms_FieldNodeMap;
/**
 * \class TPtxPdfForms_WidgetList
 */
typedef struct TPtxPdfForms_WidgetList TPtxPdfForms_WidgetList;
/**
 * \class TPtxPdfForms_SignatureFieldList
 */
typedef struct TPtxPdfForms_SignatureFieldList TPtxPdfForms_SignatureFieldList;
/**
 * \class TPtxPdfForms_Widget
 * @brief A form field widget
 */
typedef struct TPtxPdfForms_Widget TPtxPdfForms_Widget;
/**
 * \class TPtxPdfForms_FieldNode
 * @brief Base class for form fields and sub forms
 */
typedef struct TPtxPdfForms_FieldNode TPtxPdfForms_FieldNode;
/**
 * \class TPtxPdfForms_SubForm
 * @brief A form field that contains other fields
 */
typedef struct TPtxPdfForms_SubForm TPtxPdfForms_SubForm;
/**
 * \class TPtxPdfForms_Field
 * @brief A form field
 */
typedef struct TPtxPdfForms_Field TPtxPdfForms_Field;
/**
 * \class TPtxPdfForms_TextField
 * @brief A text field
 */
typedef struct TPtxPdfForms_TextField TPtxPdfForms_TextField;
/**
 * \class TPtxPdfForms_GeneralTextField
 * @brief A general text field
 */
typedef struct TPtxPdfForms_GeneralTextField TPtxPdfForms_GeneralTextField;
/**
 * \class TPtxPdfForms_CombTextField
 * @brief A fixed pitch text field
In a comb text field, the \ref PtxPdfForms_GeneralTextField_GetMaxLength "" must be defined.
The glyphs displayed are placed in \ref PtxPdfForms_GeneralTextField_GetMaxLength "" equally spaced cells.

 */
typedef struct TPtxPdfForms_CombTextField TPtxPdfForms_CombTextField;
/**
 * \class TPtxPdfForms_PushButton
 * @brief A push button field
 */
typedef struct TPtxPdfForms_PushButton TPtxPdfForms_PushButton;
/**
 * \class TPtxPdfForms_CheckBox
 * @brief A check box field
 */
typedef struct TPtxPdfForms_CheckBox TPtxPdfForms_CheckBox;
/**
 * \class TPtxPdfForms_RadioButton
 * @brief A button in a radio button group
 */
typedef struct TPtxPdfForms_RadioButton TPtxPdfForms_RadioButton;
/**
 * \class TPtxPdfForms_RadioButtonList
 */
typedef struct TPtxPdfForms_RadioButtonList TPtxPdfForms_RadioButtonList;
/**
 * \class TPtxPdfForms_RadioButtonGroup
 * @brief A radio button field
 */
typedef struct TPtxPdfForms_RadioButtonGroup TPtxPdfForms_RadioButtonGroup;
/**
 * \class TPtxPdfForms_ChoiceItem
 * @brief An item in a list box field or combo box field
 */
typedef struct TPtxPdfForms_ChoiceItem TPtxPdfForms_ChoiceItem;
/**
 * \class TPtxPdfForms_ChoiceItemList
 */
typedef struct TPtxPdfForms_ChoiceItemList TPtxPdfForms_ChoiceItemList;
/**
 * \class TPtxPdfForms_ChoiceField
 * @brief A choice field
 */
typedef struct TPtxPdfForms_ChoiceField TPtxPdfForms_ChoiceField;
/**
 * \class TPtxPdfForms_ListBox
 * @brief A list box field
 */
typedef struct TPtxPdfForms_ListBox TPtxPdfForms_ListBox;
/**
 * \class TPtxPdfForms_ComboBox
 * @brief A combo box field
 */
typedef struct TPtxPdfForms_ComboBox TPtxPdfForms_ComboBox;
/**
 * \class TPtxPdfForms_SignatureField
 * @brief A digital signature field
 */
typedef struct TPtxPdfForms_SignatureField TPtxPdfForms_SignatureField;
/**
 * \class TPtxPdfForms_SignedSignatureField
 * @brief A base class for signature fields that have been signed
The existence of a signed signature field does not imply,
that the signature is valid, the signature is actually not validated at all.

 */
typedef struct TPtxPdfForms_SignedSignatureField TPtxPdfForms_SignedSignatureField;
/**
 * \class TPtxPdfForms_Signature
 * @brief A base class for certain signature types
 */
typedef struct TPtxPdfForms_Signature TPtxPdfForms_Signature;
/**
 * \class TPtxPdfForms_DocumentSignature
 * @brief A document signature that signs the document
Document signatures are sometimes also called approval signatures.
This type of signature enables to verify the integrity of the signed part of the document and authenticate the signer’s
identity.

 */
typedef struct TPtxPdfForms_DocumentSignature TPtxPdfForms_DocumentSignature;
/**
 * \class TPtxPdfForms_DocMdpSignature
 * @brief A Document Modification Detection and Prevention (MDP) signature that certifies the document
This type of signature enables the detection of disallowed changes specified by the author.

 */
typedef struct TPtxPdfForms_DocMdpSignature TPtxPdfForms_DocMdpSignature;
/**
 * \class TPtxPdfForms_DocumentTimeStamp
 * @brief A document time-stamp signature that time-stamps the document
This type of signature provides evidence that the document existed at a specific time and protects the document’s
integrity.

 */
typedef struct TPtxPdfForms_DocumentTimeStamp TPtxPdfForms_DocumentTimeStamp;
/**
 * \class TPtxPdfNav_ViewerSettings
 */
typedef struct TPtxPdfNav_ViewerSettings TPtxPdfNav_ViewerSettings;
/**
 * \class TPtxPdfNav_OutlineItem
An outline item represents an entry in the outline tree of the document.
It is also known as "Bookmark".

 */
typedef struct TPtxPdfNav_OutlineItem TPtxPdfNav_OutlineItem;
/**
 * \class TPtxPdfNav_OutlineItemList
 */
typedef struct TPtxPdfNav_OutlineItemList TPtxPdfNav_OutlineItemList;
/**
 * \class TPtxPdfNav_Destination
A destination is a location in the document that
can be used as a jump target,
e.g. for outline items (bookmarks) or link annotations.

 */
typedef struct TPtxPdfNav_Destination TPtxPdfNav_Destination;
/**
 * \class TPtxPdfNav_NamedDestination
A named destination that can be referred by name.
Named destinations have two advantages compared to direct destinations:
  - The name can be used in web links,
e.g. http://www.example.com/document.pdf#destinationname
  - If the target destination of a named destination is changed,
all occurrences automatically point ot the new target.

 */
typedef struct TPtxPdfNav_NamedDestination TPtxPdfNav_NamedDestination;
/**
 * \class TPtxPdfNav_DirectDestination

A destination that directly points to a specific location in the document.

Note: Many PDF viewers support different viewing modes like "fit page" or
"fit width".
Most destination types will change the current viewing mode in those viewers.

Changing the viewing mode is usually not very well received by users
and thus a \ref TPtxPdfNav_LocationZoomDestination "" should be preferred in most cases.

 */
typedef struct TPtxPdfNav_DirectDestination TPtxPdfNav_DirectDestination;
/**
 * \class TPtxPdfNav_LocationZoomDestination
A destination that points to a specific location on the target page,
using a specified zoom factor.
The location is displayed in the top left corner of the viewport (if possible).

 */
typedef struct TPtxPdfNav_LocationZoomDestination TPtxPdfNav_LocationZoomDestination;
/**
 * \class TPtxPdfNav_FitPageDestination

A destination fits an entire page into the viewport.

Note: Many PDF viewers support different viewing modes like "fit page" or
"fit width".
A \ref TPtxPdfNav_FitPageDestination "" will change the current viewing mode to
"fit page" in those viewers.

Changing the viewing mode is usually not very well received by users
and thus a \ref TPtxPdfNav_LocationZoomDestination "" should be preferred in most cases.

 */
typedef struct TPtxPdfNav_FitPageDestination TPtxPdfNav_FitPageDestination;
/**
 * \class TPtxPdfNav_FitWidthDestination

A destination fits the width of a page into the viewport.

Note: Many PDF viewers support different viewing modes like "fit page" or
"fit width".
A \ref TPtxPdfNav_FitWidthDestination "" will change the current viewing mode to
"fit width" in those viewers.

Changing the viewing mode is usually not very well received by users
and thus a \ref TPtxPdfNav_LocationZoomDestination "" should be preferred in most cases.

 */
typedef struct TPtxPdfNav_FitWidthDestination TPtxPdfNav_FitWidthDestination;
/**
 * \class TPtxPdfNav_FitHeightDestination

A destination fits the height of a page into the viewport.

Note: Many PDF viewers support different viewing modes like "fit page" or
"fit width".
A \ref TPtxPdfNav_FitHeightDestination "" will change the current viewing mode to
"fit height" in those viewers.

Changing the viewing mode is usually not very well received by users
and thus a \ref TPtxPdfNav_LocationZoomDestination "" should be preferred in most cases.

 */
typedef struct TPtxPdfNav_FitHeightDestination TPtxPdfNav_FitHeightDestination;
/**
 * \class TPtxPdfNav_FitRectangleDestination

A destination that fits a specified area of a page into the viewport.

Note: Many PDF viewers support different viewing modes like "fit page" or
"fit width".
A \ref TPtxPdfNav_FitRectangleDestination "" will change the current viewing mode to
standard mode in those viewers,
i.e. deactivate any special mode like "fit page" or "fit width".

Changing the viewing mode is usually not very well received by users
and thus a \ref TPtxPdfNav_LocationZoomDestination "" should be preferred in most cases.

 */
typedef struct TPtxPdfNav_FitRectangleDestination TPtxPdfNav_FitRectangleDestination;
/**
 * \class TPtxPdfNav_Link
 * @brief A link
 */
typedef struct TPtxPdfNav_Link TPtxPdfNav_Link;
/**
 * \class TPtxPdfNav_LinkList
 */
typedef struct TPtxPdfNav_LinkList TPtxPdfNav_LinkList;
/**
 * \class TPtxPdfNav_InternalLink
 * @brief A document-wide link
 */
typedef struct TPtxPdfNav_InternalLink TPtxPdfNav_InternalLink;
/**
 * \class TPtxPdfNav_WebLink
 * @brief An external link
 */
typedef struct TPtxPdfNav_WebLink TPtxPdfNav_WebLink;
/**
 * \class TPtxPdfNav_EmbeddedPdfLink
 * @brief A link to an embedded PDF document
 */
typedef struct TPtxPdfNav_EmbeddedPdfLink TPtxPdfNav_EmbeddedPdfLink;
/**
 * \class TPtxPdfNav_OutlineCopyOptions
 */
typedef struct TPtxPdfNav_OutlineCopyOptions TPtxPdfNav_OutlineCopyOptions;
/**
 * \class TPtxPdfAnnots_Annotation
 * @brief A page annotation
 */
typedef struct TPtxPdfAnnots_Annotation TPtxPdfAnnots_Annotation;
/**
 * \class TPtxPdfAnnots_AnnotationList
 * @brief A list of annotations
When a list of \ref PtxPdf_Page_GetAnnotations "" is obtained from a page that belongs to an output document,
and this output document has been created with \ref PtxPdf_Document_CreateWithFdf "",
then getting the list count and individual elements results in a \ref ePtx_Error_UnsupportedOperation "" error.
Only appending to the list is supported in this case.

 */
typedef struct TPtxPdfAnnots_AnnotationList TPtxPdfAnnots_AnnotationList;
/**
 * \class TPtxPdfAnnots_MarkupInfo
 * @brief Information for a markup annotation
Holds information contained in a markup annotation or in a reply to a markup annotation.

 */
typedef struct TPtxPdfAnnots_MarkupInfo TPtxPdfAnnots_MarkupInfo;
/**
 * \class TPtxPdfAnnots_MarkupInfoList
 */
typedef struct TPtxPdfAnnots_MarkupInfoList TPtxPdfAnnots_MarkupInfoList;
/**
 * \class TPtxPdfAnnots_Popup
 * @brief A pop-up for a markup annotation
 */
typedef struct TPtxPdfAnnots_Popup TPtxPdfAnnots_Popup;
/**
 * \class TPtxPdfAnnots_MarkupAnnotation
 * @brief A markup annotation
 */
typedef struct TPtxPdfAnnots_MarkupAnnotation TPtxPdfAnnots_MarkupAnnotation;
/**
 * \class TPtxPdfAnnots_StickyNote
 * @brief A sticky note annotation
 */
typedef struct TPtxPdfAnnots_StickyNote TPtxPdfAnnots_StickyNote;
/**
 * \class TPtxPdfAnnots_FileAttachment
 * @brief A file attachment annotation
 */
typedef struct TPtxPdfAnnots_FileAttachment TPtxPdfAnnots_FileAttachment;
/**
 * \class TPtxPdfAnnots_Stamp
 * @brief A stamp annotation
 */
typedef struct TPtxPdfAnnots_Stamp TPtxPdfAnnots_Stamp;
/**
 * \class TPtxPdfAnnots_TextStamp
 * @brief A text stamp annotation
 */
typedef struct TPtxPdfAnnots_TextStamp TPtxPdfAnnots_TextStamp;
/**
 * \class TPtxPdfAnnots_CustomStamp
 * @brief A stamp annotation with custom content
 */
typedef struct TPtxPdfAnnots_CustomStamp TPtxPdfAnnots_CustomStamp;
/**
 * \class TPtxPdfAnnots_FreeText
 * @brief An annotation that displays text
For a free-text annotation, the annotation's content is used as text to be displayed as the annotation's visual
manifestation on the page.

 */
typedef struct TPtxPdfAnnots_FreeText TPtxPdfAnnots_FreeText;
/**
 * \class TPtxPdfAnnots_DrawingAnnotation
 * @brief A drawing annotation
An annotation used to draws something on a page.

 */
typedef struct TPtxPdfAnnots_DrawingAnnotation TPtxPdfAnnots_DrawingAnnotation;
/**
 * \class TPtxPdfAnnots_LineAnnotation
 * @brief A line annotation
An annotation that draws a line on a page.

 */
typedef struct TPtxPdfAnnots_LineAnnotation TPtxPdfAnnots_LineAnnotation;
/**
 * \class TPtxPdfAnnots_InkAnnotation
 * @brief A free-hand drawing annotation
 */
typedef struct TPtxPdfAnnots_InkAnnotation TPtxPdfAnnots_InkAnnotation;
/**
 * \class TPtxPdfAnnots_PolyLineAnnotation
 * @brief A drawing annotation that consists of several line segments
 */
typedef struct TPtxPdfAnnots_PolyLineAnnotation TPtxPdfAnnots_PolyLineAnnotation;
/**
 * \class TPtxPdfAnnots_PolygonAnnotation
 * @brief A polygon annotation
 */
typedef struct TPtxPdfAnnots_PolygonAnnotation TPtxPdfAnnots_PolygonAnnotation;
/**
 * \class TPtxPdfAnnots_RectangleAnnotation
 * @brief A rectangle drawing annotation
 */
typedef struct TPtxPdfAnnots_RectangleAnnotation TPtxPdfAnnots_RectangleAnnotation;
/**
 * \class TPtxPdfAnnots_EllipseAnnotation
 * @brief An ellipse drawing annotation
 */
typedef struct TPtxPdfAnnots_EllipseAnnotation TPtxPdfAnnots_EllipseAnnotation;
/**
 * \class TPtxPdfAnnots_TextMarkup
 * @brief An annotation that marks up part(s) of a text
 */
typedef struct TPtxPdfAnnots_TextMarkup TPtxPdfAnnots_TextMarkup;
/**
 * \class TPtxPdfAnnots_Highlight
 * @brief An text highlighting annotation
 */
typedef struct TPtxPdfAnnots_Highlight TPtxPdfAnnots_Highlight;
/**
 * \class TPtxPdfAnnots_Underline
 * @brief An text underlining annotation
 */
typedef struct TPtxPdfAnnots_Underline TPtxPdfAnnots_Underline;
/**
 * \class TPtxPdfAnnots_StrikeThrough
 * @brief An annotation for striking through text
 */
typedef struct TPtxPdfAnnots_StrikeThrough TPtxPdfAnnots_StrikeThrough;
/**
 * \class TPtxPdfAnnots_Squiggly
 * @brief A squiggly text underlining annotation
 */
typedef struct TPtxPdfAnnots_Squiggly TPtxPdfAnnots_Squiggly;
/**
 * \class TPtxPdfAnnots_TextInsert
 * @brief An annotation that marks a point to insert text
 */
typedef struct TPtxPdfAnnots_TextInsert TPtxPdfAnnots_TextInsert;

/**
 */
typedef struct TPtxGeomReal_Point
{
    /**
     * @brief The X value (horizontal coordinate).
     */
    double dX;
    /**
     * @brief The Y value (vertical coordinate).
     */
    double dY;
} TPtxGeomReal_Point;

/**
 */
typedef struct TPtxGeomReal_Size
{
    /**
     * @brief The Width value (horizontal size).
     */
    double dWidth;
    /**
     * @brief The Height value (vertical size).
     */
    double dHeight;
} TPtxGeomReal_Size;

/**
 */
typedef struct TPtxGeomReal_Rectangle
{
    /**
     * @brief The Left value.
     */
    double dLeft;
    /**
     * @brief The Bottom value.
     */
    double dBottom;
    /**
     * @brief The Right value.
     */
    double dRight;
    /**
     * @brief The Top value.
     */
    double dTop;
} TPtxGeomReal_Rectangle;

/**
A quadrilateral is a polygon with four sides and four corners.
When associated with text, the horizontal text writing direction goes from \ref TPtxGeomReal_Quadrilateral#BottomLeft ""
to \ref TPtxGeomReal_Quadrilateral#BottomLeft "".

 */
typedef struct TPtxGeomReal_Quadrilateral
{
    /**
     */
    TPtxGeomReal_Point BottomLeft;
    /**
     */
    TPtxGeomReal_Point BottomRight;
    /**
     */
    TPtxGeomReal_Point TopRight;
    /**
     */
    TPtxGeomReal_Point TopLeft;
} TPtxGeomReal_Quadrilateral;

/**
 */
typedef struct TPtxGeomReal_AffineTransform
{
    /**
     * @brief The 'a' matrix element.
    This is the 'a' element in the affine transformation matrix [a b 0; c d 0; e f 1]

     */
    double dA;
    /**
     * @brief The 'b' matrix element.
    This is the 'b' element in the affine transformation matrix [a b 0; c d 0; e f 1]

     */
    double dB;
    /**
     * @brief The 'c' matrix element.
    This is the 'c' element in the affine transformation matrix [a b 0; c d 0; e f 1]

     */
    double dC;
    /**
     * @brief The 'd' matrix element.
    This is the 'd' element in the affine transformation matrix [a b 0; c d 0; e f 1]

     */
    double dD;
    /**
     * @brief The 'e' matrix element.
    This is the 'e' element in the affine transformation matrix [a b 0; c d 0; e f 1]

     */
    double dE;
    /**
     * @brief The 'f' matrix element.
    This is the 'f' element in the affine transformation matrix [a b 0; c d 0; e f 1]

     */
    double dF;
} TPtxGeomReal_AffineTransform;

/**
 */
typedef struct TPtxGeomInt_Size
{
    /**
     * @brief The width (horizontal size).
     */
    int iWidth;
    /**
     * @brief The height (vertical size).
     */
    int iHeight;
} TPtxGeomInt_Size;

/**
 */
typedef struct TPtxPdfContent_PathSegment
{
    /**
     * @brief The end point of the path segment.
    The start point of the segment corresponds to the end point of the previous segment.

     */
    TPtxGeomReal_Point EndPoint;
    /**
    Defines the type of this path segment.

     */
    TPtxPdfContent_PathSegmentType iSegmentType;
    /**
     * @brief The first Bezier control point.
    Only valid if the \ref TPtxPdfContent_PathSegment#EndPoint "" is set to \ref ePtxPdfContent_PathSegmentType_Cubic ""

     */
    TPtxGeomReal_Point ControlPoint1;
    /**
     * @brief The second Bezier control point.
    Only valid if the \ref TPtxPdfContent_PathSegment#EndPoint "" is set to \ref ePtxPdfContent_PathSegmentType_Cubic ""

     */
    TPtxGeomReal_Point ControlPoint2;
} TPtxPdfContent_PathSegment;

/**
 */
typedef struct TPtxPdfNav_PageDisplay
{
    /**
     */
    TPtxPdfNav_PageLayout iPageLayout;
    /**
     */
    BOOL bContinuous;
} TPtxPdfNav_PageDisplay;

typedef struct TPtxSys_Date
{
    short iYear;
    short iMonth;
    short iDay;
    short iHour;
    short iMinute;
    short iSecond;
    short iTZSign;
    short iTZHour;
    short iTZMinute;
} TPtxSys_Date;

struct TPtxSys_StreamDescriptor;

#ifdef __cplusplus
}
#endif

#endif /* PDFTOOLS_TOOLBOX_TYPES_H__ */
